==> pydftracer-1.0.11-cp39-cp39-manylinux_2_39_x86_64.whl: dftracer/etc/modulefiles/cpp-logger-1.0.0.lua <==
-- LMod module file for CPP_LOGGER

-- CMAKE_INSTALL_PREFIX: /home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-cpython-39/dftracer
-- CMAKE_BUILD_TYPE: Release
-- C Compiler: /usr/bin/cc
-- C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations
-- C FLAGS_DEBUG: -g
-- C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- C FLAGS_RELEASE: -O3 -DNDEBUG
-- CXX Compiler: /usr/bin/c++
-- CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations
-- CXX FLAGS_DEBUG: -g
-- CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- CXX FLAGS_RELEASE: -O3 -DNDEBUG
-- CPP_LOGGER_GNU_LINUX: TRUE
-- CPP_LOGGER_HAS_DOXYGEN: 

help(
[[
CPP Logger (CPP_LOGGER) version (0, 0, 4).
]])

whatis("Package: CPP_LOGGER")
whatis("Version: (0, 0, 4)")
whatis("Description: DYnamic and Asynchronous Data streamliner (CPP_LOGGER).")
whatis("URL: https://github.com/flux-framework/cpp_logger")
whatis("CMAKE_INSTALL_PREFIX: /home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-cpython-39/dftracer")
whatis("CMAKE_BUILD_TYPE: Release")
whatis("C Compiler: /usr/bin/cc")
whatis("C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations")
whatis("C FLAGS_DEBUG: -g")
whatis("C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("C FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("CXX Compiler: /usr/bin/c++")
whatis("CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations")
whatis("CXX FLAGS_DEBUG: -g")
whatis("CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("CXX FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("CPP_LOGGER_GNU_LINUX: TRUE")
whatis("CPP_LOGGER_HAS_DOXYGEN: ")

prepend_path("PATH","/home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-cpython-39/dftracer/bin")
prepend_path("LD_LIBRARY_PATH","/home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-cpython-39/dftracer/lib")

pushenv("CPP_LOGGER_DIR","/home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-cpython-39/dftracer/")

==> pydftracer-1.0.12.dev0-cp39-cp39-manylinux_2_34_x86_64.whl: dftracer/etc/modulefiles/cpp-logger-1.0.0.lua <==
-- LMod module file for CPP_LOGGER

-- CMAKE_INSTALL_PREFIX: /home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-3.9/dftracer
-- CMAKE_BUILD_TYPE: Release
-- C Compiler: /usr/bin/cc
-- C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations
-- C FLAGS_DEBUG: -g
-- C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- C FLAGS_RELEASE: -O3 -DNDEBUG
-- CXX Compiler: /usr/bin/c++
-- CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations
-- CXX FLAGS_DEBUG: -g
-- CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- CXX FLAGS_RELEASE: -O3 -DNDEBUG
-- CPP_LOGGER_GNU_LINUX: TRUE
-- CPP_LOGGER_HAS_DOXYGEN: 

help(
[[
CPP Logger (CPP_LOGGER) version (0, 0, 4).
]])

whatis("Package: CPP_LOGGER")
whatis("Version: (0, 0, 4)")
whatis("Description: DYnamic and Asynchronous Data streamliner (CPP_LOGGER).")
whatis("URL: https://github.com/flux-framework/cpp_logger")
whatis("CMAKE_INSTALL_PREFIX: /home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-3.9/dftracer")
whatis("CMAKE_BUILD_TYPE: Release")
whatis("C Compiler: /usr/bin/cc")
whatis("C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations")
whatis("C FLAGS_DEBUG: -g")
whatis("C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("C FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("CXX Compiler: /usr/bin/c++")
whatis("CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations")
whatis("CXX FLAGS_DEBUG: -g")
whatis("CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("CXX FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("CPP_LOGGER_GNU_LINUX: TRUE")
whatis("CPP_LOGGER_HAS_DOXYGEN: ")

prepend_path("PATH","/home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-3.9/dftracer/bin")
prepend_path("LD_LIBRARY_PATH","/home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-3.9/dftracer/lib")

pushenv("CPP_LOGGER_DIR","/home/runner/work/dftracer/dftracer/build/lib.linux-x86_64-3.9/dftracer/")
